===========================================
Projects Deployment Configuration Reference
===========================================

.. toctree::
   :maxdepth: 2

   compute/index
   bare-metal/index
   storage/index
   networking/index
   shared-services/index
   orchestration-and-nfv/index
   logging-and-monitoring/index
   containers/index
   databases/index
   deployment-config/index
   deployment-and-bootstrapping/index
